@@ -364,10 +364,9 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-@EXPORT = qw(set);
 @EXPORT_OK = qw( ish_int is_int is_string is_double blessed reftype
-		 refaddr is_overloaded is_object is_key );
-$VERSION = '1.11';
+		 refaddr is_overloaded is_object is_key set );
+$VERSION = '1.12';
 
 bootstrap Set::Object $VERSION;
 
